@@ -13,7 +13,7 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 log=logging.getLogger(__name__)
 log.setLevel(logging.WARNING)
 formatter = logging.Formatter(
-    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    fmt="%(asctime)s | %(levelname)s | thread-%(threadName)s | %(filename)s:%(lineno)d | %(message)s",
     datefmt="%Y-%m-%d %H:%M:%S"
 )
 console_handler = logging.StreamHandler()
